@@ -14,14 +14,16 @@ KEY__records_filtered = "records_filtered"
 KEY__data = "data"
 KEY__db_url = "db_url"
 KEY__precedence = "precedence"
+KEY__roles = "roles"
+KEY__pre_auth_key = "pre_auth_key"
 KEY__email = "email"
 KEY__sort = "sort"
 KEY__invite_key = "invite_key"
 KEY__search = "search"
-KEY__parameter_name = "parameter_name"
 KEY__application_name = "name"
-KEY__parameter = "parameter"
-KEY__parameter_description = "parameter_description"
+KEY__dataset = "dataset"
+KEY__dataset_name = "name"
+KEY__dataset_description = "dataset_description"
 KEY__size = "size"
 KEY__database = "database"
 KEY__node_name = "name"
@@ -32,12 +34,15 @@ KEY__connection = "connection"
 KEY__node = "node"
 KEY__application_url = "url"
 KEY__role = "role"
+KEY__roles = "roles"
 KEY__mfa_key = "mfa_key"
+KEY__mfa_enabled = "mfa_enabled"
 KEY__username = "username"
 KEY__password = "password"
 KEY__new_password = "new_password"
 KEY__new_password_confirm = "new_password_confirm"
 KEY__page = "page"
+KEY__use_mfa = "use_mfa"
 KEY__show_deleted = "show_deleted"
 KEY__description = "description"
 KEY__database_name = "name"
@@ -86,4 +91,4 @@ JAAQL__arg_marker = ":"
 ENCODING__utf = "UTF-8"
 EXAMPLE__jwt = "eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.e30.yXvILkvUUCBqAFlAv6wQ1Q-QRAjfe3eSosO949U73Vo"
 
-VERSION = "2.1.5"
+VERSION = "2.2.0"
